@@ -245,7 +245,6 @@ pyerl_element(PyObject *self, PyObject *args)
 	if(!(ret = (EtermObject *)EtermType.tp_new(&EtermType, NULL, NULL))){
 		return NULL;
 	}
-	printf("1\n");
 	etuple = (EtermObject *)tuple;
 	if(!etuple->term){
 		return NULL;
@@ -258,6 +257,62 @@ pyerl_element(PyObject *self, PyObject *args)
 	return Py_BuildValue("O", ret);
 }
 
+static PyObject *
+pyerl_hd(PyObject *self, PyObject *args)
+{
+	EtermObject *ret;
+	PyObject *term;
+	EtermObject *eterm;
+
+	if (!PyArg_ParseTuple(args, "O", &term)){
+		return NULL;
+	}
+	if(!PyObject_TypeCheck(term, &EtermType)){
+		return NULL;
+	}
+	if(!(ret = (EtermObject *)EtermType.tp_new(&EtermType, NULL, NULL))){
+		return NULL;
+	}
+	eterm = (EtermObject *)term;
+	if(!eterm->term){
+		return NULL;
+	}
+	ret->term = erl_hd(eterm->term);
+	if(!ret->term){
+		EtermType.tp_dealloc((PyObject *)ret);
+		Py_RETURN_NONE;
+	}
+	return Py_BuildValue("O", ret);
+}
+
+static PyObject *
+pyerl_tl(PyObject *self, PyObject *args)
+{
+	EtermObject *ret;
+	PyObject *term;
+	EtermObject *eterm;
+
+	if (!PyArg_ParseTuple(args, "O", &term)){
+		return NULL;
+	}
+	if(!PyObject_TypeCheck(term, &EtermType)){
+		return NULL;
+	}
+	if(!(ret = (EtermObject *)EtermType.tp_new(&EtermType, NULL, NULL))){
+		return NULL;
+	}
+	eterm = (EtermObject *)term;
+	if(!eterm->term){
+		return NULL;
+	}
+	ret->term = erl_tl(eterm->term);
+	if(!ret->term){
+		EtermType.tp_dealloc((PyObject *)ret);
+		Py_RETURN_NONE;
+	}
+	return Py_BuildValue("O", ret);
+}
+
 static PyObject *
 pyerl_mk_atom(PyObject *self, PyObject *args)
 {
@@ -646,9 +701,11 @@ pyerl_print_term(PyObject *self, PyObject *args)
 	if (!PyArg_ParseTuple(args, "OO", &stream, &term)){
 		return NULL;
 	}
-	if(PyFile_Check(stream)){
-		fp = PyFile_AsFile(stream);
-	}else{
+	if(!PyFile_Check(stream)){
+		return NULL;
+	}
+	fp = PyFile_AsFile(stream);
+	if(!PyObject_TypeCheck(term, &EtermType)){
 		return NULL;
 	}
 	eterm = (EtermObject *)term;
@@ -709,6 +766,8 @@ static PyMethodDef methods[] = {
 	{"cons", pyerl_cons, METH_VARARGS, NULL},
 	{"copy_term", pyerl_copy_term, METH_VARARGS, NULL},
 	{"element", pyerl_element, METH_VARARGS, NULL},
+	{"hd", pyerl_hd, METH_VARARGS, NULL},
+	{"tl", pyerl_tl, METH_VARARGS, NULL},
 
 	{"mk_atom", pyerl_mk_atom, METH_VARARGS, NULL},
 	{"mk_binary", pyerl_mk_binary, METH_VARARGS, NULL},
